# CLI Reference

The Agent Starter Pack provides a command-line interface (CLI) to create and setup Generative AI Agent templates in Google Cloud. 

## Available Commands

- [`create`](create.md) - Create a new generative AI application project
- [`setup-cicd`](setup_cicd.md) - Set up CI/CD pipeline for your project

For detailed usage instructions, click on the command links above.
